changeset 16874:f160f9029b4e

Add deprecated compiler flag to Octave_map class. * libinterp/interp-core/oct-map.h: Add GCC_DEPRECATED_ATTR mark on Octave_map class.
author Rik <rik@octave.org>
date Sun, 30 Jun 2013 13:11:03 -0700
parents 898f902006df
children b04ae15530fc
files libinterp/interp-core/oct-map.h
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/libinterp/interp-core/oct-map.h
+++ b/libinterp/interp-core/oct-map.h
@@ -473,8 +473,8 @@
 inline octave_map octave_value_extract<octave_map> (const octave_value& v)
   { return v.map_value (); }
 
 // The original Octave_map object. Octave_map and octave_map are convertible to
 // each other.
 
 class
 OCTINTERP_API
@@ -654,6 +654,6 @@
       if (! contains (k))
         key_list.push_back (k);
     }
-};
+} GCC_ATTR_DEPRECATED;
 
 #endif
@@ -473,8 +473,8 @@
   { return v.map_value (); }
 
-// The original Octave_map object. Octave_map and octave_map are convertible to
-// each other.
+// The original Octave_map object which is now deprecated.
+// Octave_map and octave_map are convertible to each other.
 
 class